#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


from pyams_content.component.paragraph.interfaces.map import have_gis
if have_gis:

    # import standard library

    # import interfaces
    from onf_website.component.paragraph.interfaces.map import IMapParagraph
    from onf_website.component.paragraph.skin.interfaces.map import IMapParagraphDefaultRendererSettings
    from pyams_content.features.renderer import IContentRenderer
    from pyams_skin.layer import IPyAMSLayer

    # import packages
    from pyams_default_theme.component.paragraph.map import MAP_DEFAULT_RENDERER_SETTINGS_KEY, \
        MapParagraphDefaultRenderer as BaseMapParagraphDefaultRenderer, \
        MapParagraphDefaultRendererSettings as BaseMapParagraphDefaultRendererSettings
    from pyams_template.template import template_config
    from pyams_utils.adapter import adapter_config, get_annotation_adapter
    from zope.interface import implementer
    from zope.schema.fieldproperty import FieldProperty


    @implementer(IMapParagraphDefaultRendererSettings)
    class MapParagraphDefaultRendererSettings(BaseMapParagraphDefaultRendererSettings):
        """Map paragraph default renderer settings"""

        display_context_forests = FieldProperty(IMapParagraphDefaultRendererSettings['display_context_forests'])
        set_bounds_to_forests = FieldProperty(IMapParagraphDefaultRendererSettings['set_bounds_to_forests'])


    @adapter_config(context=IMapParagraph, provides=IMapParagraphDefaultRendererSettings)
    def map_paragraph_default_renderer_settings_factory(context):
        """Map paragraph default renderer settings factory"""
        return get_annotation_adapter(context, MAP_DEFAULT_RENDERER_SETTINGS_KEY,
                                      MapParagraphDefaultRendererSettings)


    #
    # Map paragraph default renderer
    #

    @adapter_config(name='default', context=(IMapParagraph, IPyAMSLayer), provides=IContentRenderer)
    @template_config(template='templates/map-default.pt', layer=IPyAMSLayer)
    class MapParagraphDefaultRenderer(BaseMapParagraphDefaultRenderer):
        """Mpp paragraph default renderer"""

        settings_interface = IMapParagraphDefaultRendererSettings
